===================
The ESA CCI Toolbox
===================

The ESA CCI Toolbox is a Python package designed to provide access
to CCI data from the ESA Open Data Portal.
For information on available data, `click here <https://climate.esa.int/de/odp/#/dashboard>`_.
These pages shall serve to explain the purpose and usage of the Toolbox.
They will be extended while the toolbox is extended with functionality.

Also, the toolbox contains functions to operate on this data.
